from _typeshed import Incomplete
from typing import type_check_only
from typing_extensions import final

from pyasn1.type import constraint, namedtype
from pyasn1.type.tag import TagSet

class Asn1Item:
    @classmethod
    def getTypeId(cls, increment: int = ...): ...

class Asn1Type(Asn1Item):
    tagSet: TagSet
    subtypeSpec: constraint.ConstraintsIntersection
    typeId: int | None
    def __init__(self, **kwargs) -> None: ...
    def __setattr__(self, name, value) -> None: ...
    @property
    def readOnly(self): ...
    @property
    def effectiveTagSet(self): ...
    @property
    def tagMap(self): ...
    def isSameTypeWith(self, other, matchTags: bool = ..., matchConstraints: bool = ...): ...
    def isSuperTypeOf(self, other, matchTags: bool = ..., matchConstraints: bool = ...): ...
    @staticmethod
    def isNoValue(*values): ...
    def prettyPrint(self, scope: int = ...) -> None: ...
    def getTagSet(self): ...
    def getEffectiveTagSet(self): ...
    def getTagMap(self): ...
    def getSubtypeSpec(self): ...
    def hasValue(self): ...

Asn1ItemBase = Asn1Type

@final
class NoValue:
    skipMethods: set[str]
    def __new__(cls): ...
    def __getattr__(self, attr) -> None: ...
    # def __new__.<locals>.getPlug.<locals>.plug
    @type_check_only
    def plug(self, *args: object, **kw: object): ...
    # Magic methods assigned dynamically, priority from right to left: plug < str < int < list < dict
    __abs__ = int.__abs__
    __add__ = list.__add__
    __and__ = int.__and__
    __bool__ = int.__bool__
    __ceil__ = int.__ceil__
    __class_getitem__ = plug
    __contains__ = dict.__contains__
    __delitem__ = dict.__delitem__
    __dir__ = plug
    __divmod__ = int.__divmod__
    __float__ = int.__float__
    __floor__ = int.__floor__
    __floordiv__ = int.__floordiv__
    __ge__ = list.__ge__
    __getitem__ = dict.__getitem__
    __gt__ = list.__gt__
    __iadd__ = list.__iadd__
    __imul__ = list.__imul__
    __index__ = int.__index__
    # self instead of cls
    __init_subclass__ = plug  # pyright: ignore[reportGeneralTypeIssues]
    __int__ = int.__int__
    __invert__ = int.__invert__
    __ior__ = plug
    __iter__ = dict.__iter__
    __le__ = list.__le__
    __len__ = dict.__len__
    __lshift__ = int.__lshift__
    __lt__ = list.__lt__
    __mod__ = int.__mod__
    __mul__ = list.__mul__
    __neg__ = int.__neg__
    __or__ = int.__or__
    __pos__ = int.__pos__
    __pow__ = int.__pow__
    __radd__ = int.__radd__
    __rand__ = int.__rand__
    __rdivmod__ = int.__rdivmod__
    __reversed__ = list.__reversed__
    __rfloordiv__ = int.__rfloordiv__
    __rlshift__ = int.__rlshift__
    __rmod__ = int.__rmod__
    __rmul__ = list.__rmul__
    __ror__ = int.__ror__
    __round__ = int.__round__
    __rpow__ = int.__rpow__
    __rrshift__ = int.__rrshift__
    __rshift__ = int.__rshift__
    __rsub__ = int.__rsub__
    __rtruediv__ = int.__rtruediv__
    __rxor__ = int.__rxor__
    __setitem__ = list.__setitem__
    __str__ = plug
    __sub__ = int.__sub__
    __truediv__ = int.__truediv__
    __trunc__ = int.__trunc__
    __xor__ = int.__xor__

class SimpleAsn1Type(Asn1Type):
    defaultValue: Incomplete | NoValue
    def __init__(self, value=..., **kwargs) -> None: ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...
    def __bool__(self) -> bool: ...
    def __hash__(self): ...
    @property
    def isValue(self): ...
    def clone(self, value=..., **kwargs): ...
    def subtype(self, value=..., **kwargs): ...
    def prettyIn(self, value): ...
    def prettyOut(self, value): ...
    def prettyPrint(self, scope: int = ...): ...
    def prettyPrintType(self, scope: int = ...): ...

AbstractSimpleAsn1Item = SimpleAsn1Type

class ConstructedAsn1Type(Asn1Type):
    strictConstraints: bool
    componentType: namedtype.NamedTypes | None
    sizeSpec: constraint.ConstraintsIntersection
    def __init__(self, **kwargs) -> None: ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...
    def __bool__(self) -> bool: ...
    @property
    def components(self) -> None: ...
    def clone(self, **kwargs): ...
    def subtype(self, **kwargs): ...
    def getComponentByPosition(self, idx) -> None: ...
    def setComponentByPosition(self, idx, value, verifyConstraints: bool = ...) -> None: ...
    def setComponents(self, *args, **kwargs): ...
    def setDefaultComponents(self) -> None: ...
    def getComponentType(self): ...
    def verifySizeSpec(self) -> None: ...

AbstractConstructedAsn1Item = ConstructedAsn1Type



from _typeshed import Incomplete
from abc import ABCMeta, abstractmethod
from collections.abc import Callable
from typing_extensions import TypeAlias

from pyasn1.type import base, char, univ, useful
from pyasn1.type.base import Asn1Type
from pyasn1.type.tag import TagSet

_Unused: TypeAlias = object

class AbstractDecoder:
    protoComponent: Asn1Type | None
    @abstractmethod
    def valueDecoder(
        self,
        substrate,
        asn1Spec,
        tagSet: TagSet | None = ...,
        length: int | None = ...,
        state: Incomplete | None = ...,
        decodeFun: Callable[..., Incomplete] | None = ...,
        substrateFun: Callable[..., Incomplete] | None = ...,
        **options,
    ) -> None: ...
    # Abstract, but implementation is optional
    def indefLenValueDecoder(
        self,
        substrate,
        asn1Spec,
        tagSet: TagSet | None = ...,
        length: int | None = ...,
        state: Incomplete | None = ...,
        decodeFun: Callable[..., Incomplete] | None = ...,
        substrateFun: Callable[..., Incomplete] | None = ...,
        **options,
    ) -> None: ...

class AbstractSimpleDecoder(AbstractDecoder, metaclass=ABCMeta):
    @staticmethod
    def substrateCollector(asn1Object, substrate, length): ...

class ExplicitTagDecoder(AbstractSimpleDecoder):
    protoComponent: univ.Any
    def valueDecoder(
        self,
        substrate,
        asn1Spec,
        tagSet: TagSet | None = ...,
        length: int | None = ...,
        state: _Unused = ...,
        decodeFun: Callable[..., Incomplete] | None = ...,
        substrateFun: Callable[..., Incomplete] | None = ...,
        **options,
    ): ...
    def indefLenValueDecoder(
        self,
        substrate,
        asn1Spec,
        tagSet: TagSet | None = ...,
        length: int | None = ...,
        state: _Unused = ...,
        decodeFun: Callable[..., Incomplete] | None = ...,
        substrateFun: Callable[..., Incomplete] | None = ...,
        **options,
    ): ...

class IntegerDecoder(AbstractSimpleDecoder):
    protoComponent: univ.Integer
    def valueDecoder(
        self,
        substrate,
        asn1Spec,
        tagSet: TagSet | None = ...,
        length: int | None = ...,
        state: _Unused = ...,
        decodeFun: _Unused = ...,
        substrateFun: _Unused = ...,
        **options,
    ): ...

class BooleanDecoder(IntegerDecoder):
    protoComponent: univ.Boolean

class BitStringDecoder(AbstractSimpleDecoder):
    protoComponent: univ.BitString
    supportConstructedForm: bool
    def valueDecoder(
        self,
        substrate,
        asn1Spec,
        tagSet: TagSet | None = ...,
        length: int | None = ...,
        state: _Unused = ...,
        decodeFun: Callable[..., Incomplete] | None = ...,
        substrateFun: Callable[..., Incomplete] | None = ...,
        **options,
    ): ...
    def indefLenValueDecoder(
        self,
        substrate,
        asn1Spec,
        tagSet: TagSet | None = ...,
        length: int | None = ...,
        state: _Unused = ...,
        decodeFun: Callable[..., Incomplete] | None = ...,
        substrateFun: Callable[..., Incomplete] | None = ...,
        **options,
    ): ...

class OctetStringDecoder(AbstractSimpleDecoder):
    protoComponent: univ.OctetString
    supportConstructedForm: bool
    def valueDecoder(
        self,
        substrate,
        asn1Spec,
        tagSet: TagSet | None = ...,
        length: int | None = ...,
        state: _Unused = ...,
        decodeFun: Callable[..., Incomplete] | None = ...,
        substrateFun: Callable[..., Incomplete] | None = ...,
        **options,
    ): ...
    def indefLenValueDecoder(
        self,
        substrate,
        asn1Spec,
        tagSet: TagSet | None = ...,
        length: int | None = ...,
        state: _Unused = ...,
        decodeFun: Callable[..., Incomplete] | None = ...,
        substrateFun: Callable[..., Incomplete] | None = ...,
        **options,
    ): ...

class NullDecoder(AbstractSimpleDecoder):
    protoComponent: univ.Null
    def valueDecoder(
        self,
        substrate,
        asn1Spec,
        tagSet: TagSet | None = ...,
        length: int | None = ...,
        state: _Unused = ...,
        decodeFun: _Unused = ...,
        substrateFun: _Unused = ...,
        **options,
    ): ...

class ObjectIdentifierDecoder(AbstractSimpleDecoder):
    protoComponent: univ.ObjectIdentifier
    def valueDecoder(
        self,
        substrate,
        asn1Spec,
        tagSet: TagSet | None = ...,
        length: int | None = ...,
        state: _Unused = ...,
        decodeFun: _Unused = ...,
        substrateFun: _Unused = ...,
        **options,
    ): ...

class RealDecoder(AbstractSimpleDecoder):
    protoComponent: univ.Real
    def valueDecoder(
        self,
        substrate,
        asn1Spec,
        tagSet: TagSet | None = ...,
        length: int | None = ...,
        state: _Unused = ...,
        decodeFun: _Unused = ...,
        substrateFun: _Unused = ...,
        **options,
    ): ...

class AbstractConstructedDecoder(AbstractDecoder, metaclass=ABCMeta):
    protoComponent: base.ConstructedAsn1Type | None

class UniversalConstructedTypeDecoder(AbstractConstructedDecoder):
    protoRecordComponent: univ.SequenceAndSetBase | None
    protoSequenceComponent: univ.SequenceOfAndSetOfBase | None
    def valueDecoder(
        self,
        substrate,
        asn1Spec,
        tagSet: TagSet | None = ...,
        length: int | None = ...,
        state: _Unused = ...,
        decodeFun: Callable[..., Incomplete] | None = ...,
        substrateFun: Callable[..., Incomplete] | None = ...,
        **options,
    ): ...
    def indefLenValueDecoder(
        self,
        substrate,
        asn1Spec,
        tagSet: TagSet | None = ...,
        length: int | None = ...,
        state: _Unused = ...,
        decodeFun: Callable[..., Incomplete] | None = ...,
        substrateFun: Callable[..., Incomplete] | None = ...,
        **options,
    ): ...

class SequenceOrSequenceOfDecoder(UniversalConstructedTypeDecoder):
    protoRecordComponent: univ.Sequence
    protoSequenceComponent: univ.SequenceOf

class SequenceDecoder(SequenceOrSequenceOfDecoder):
    protoComponent: univ.Sequence

class SequenceOfDecoder(SequenceOrSequenceOfDecoder):
    protoComponent: univ.SequenceOf

class SetOrSetOfDecoder(UniversalConstructedTypeDecoder):
    protoRecordComponent: univ.Set
    protoSequenceComponent: univ.SetOf

class SetDecoder(SetOrSetOfDecoder):
    protoComponent: univ.Set

class SetOfDecoder(SetOrSetOfDecoder):
    protoComponent: univ.SetOf

class ChoiceDecoder(AbstractConstructedDecoder):
    protoComponent: univ.Choice
    def valueDecoder(
        self,
        substrate,
        asn1Spec,
        tagSet: TagSet | None = ...,
        length: int | None = ...,
        state: Incomplete | None = ...,
        decodeFun: Callable[..., Incomplete] | None = ...,
        substrateFun: Callable[..., Incomplete] | None = ...,
        **options,
    ): ...
    def indefLenValueDecoder(
        self,
        substrate,
        asn1Spec,
        tagSet: TagSet | None = ...,
        length: int | None = ...,
        state: Incomplete | None = ...,
        decodeFun: Callable[..., Incomplete] | None = ...,
        substrateFun: Callable[..., Incomplete] | None = ...,
        **options,
    ): ...

class AnyDecoder(AbstractSimpleDecoder):
    protoComponent: univ.Any
    def valueDecoder(
        self,
        substrate,
        asn1Spec,
        tagSet: TagSet | None = ...,
        length: int | None = ...,
        state: _Unused = ...,
        decodeFun: _Unused = ...,
        substrateFun: Callable[..., Incomplete] | None = ...,
        **options,
    ): ...
    def indefLenValueDecoder(
        self,
        substrate,
        asn1Spec,
        tagSet: TagSet | None = ...,
        length: int | None = ...,
        state: _Unused = ...,
        decodeFun: Callable[..., Incomplete] | None = ...,
        substrateFun: Callable[..., Incomplete] | None = ...,
        **options,
    ): ...

class UTF8StringDecoder(OctetStringDecoder):
    protoComponent: char.UTF8String

class NumericStringDecoder(OctetStringDecoder):
    protoComponent: char.NumericString

class PrintableStringDecoder(OctetStringDecoder):
    protoComponent: char.PrintableString

class TeletexStringDecoder(OctetStringDecoder):
    protoComponent: char.TeletexString

class VideotexStringDecoder(OctetStringDecoder):
    protoComponent: char.VideotexString

class IA5StringDecoder(OctetStringDecoder):
    protoComponent: char.IA5String

class GraphicStringDecoder(OctetStringDecoder):
    protoComponent: char.GraphicString

class VisibleStringDecoder(OctetStringDecoder):
    protoComponent: char.VisibleString

class GeneralStringDecoder(OctetStringDecoder):
    protoComponent: char.GeneralString

class UniversalStringDecoder(OctetStringDecoder):
    protoComponent: char.UniversalString

class BMPStringDecoder(OctetStringDecoder):
    protoComponent: char.BMPString

class ObjectDescriptorDecoder(OctetStringDecoder):
    protoComponent: useful.ObjectDescriptor

class GeneralizedTimeDecoder(OctetStringDecoder):
    protoComponent: useful.GeneralizedTime

class UTCTimeDecoder(OctetStringDecoder):
    protoComponent: useful.UTCTime

class Decoder:
    defaultErrorState: int
    defaultRawDecoder: AnyDecoder
    supportIndefLength: bool
    def __init__(self, tagMap, typeMap=...) -> None: ...
    def __call__(
        self,
        substrate,
        asn1Spec: Asn1Type | None = ...,
        tagSet: TagSet | None = ...,
        length: int | None = ...,
        state=...,
        decodeFun: _Unused = ...,
        substrateFun: Callable[..., Incomplete] | None = ...,
        **options,
    ): ...

decode: Decoder



from _typeshed import Incomplete
from collections.abc import Callable
from typing_extensions import TypeAlias

_Unused: TypeAlias = object

class AbstractScalarDecoder:
    def __call__(self, pyObject, asn1Spec, decodeFun: _Unused = ..., **options): ...

class BitStringDecoder(AbstractScalarDecoder):
    def __call__(self, pyObject, asn1Spec, decodeFun: _Unused = ..., **options): ...

class SequenceOrSetDecoder:
    def __call__(self, pyObject, asn1Spec, decodeFun: Callable[..., Incomplete] | None = ..., **options): ...

class SequenceOfOrSetOfDecoder:
    def __call__(self, pyObject, asn1Spec, decodeFun: Callable[..., Incomplete] | None = ..., **options): ...

class ChoiceDecoder:
    def __call__(self, pyObject, asn1Spec, decodeFun: Callable[..., Incomplete] | None = ..., **options): ...

class Decoder:
    def __init__(self, tagMap, typeMap) -> None: ...
    def __call__(self, pyObject, asn1Spec, **options): ...

decode: Decoder



from typing_extensions import TypeAlias

from pyasn1.codec.ber import decoder
from pyasn1.type import univ
from pyasn1.type.tag import TagSet

_Unused: TypeAlias = object

class BooleanDecoder(decoder.AbstractSimpleDecoder):
    protoComponent: univ.Boolean
    def valueDecoder(
        self,
        substrate,
        asn1Spec,
        tagSet: TagSet | None = ...,
        length: int | None = ...,
        state: _Unused = ...,
        decodeFun: _Unused = ...,
        substrateFun: _Unused = ...,
        **options,
    ): ...

BitStringDecoder = decoder.BitStringDecoder
OctetStringDecoder = decoder.OctetStringDecoder
RealDecoder = decoder.RealDecoder

class Decoder(decoder.Decoder): ...

decode: Decoder



from typing_extensions import Literal

implementation: str
null: Literal[b""]

def from_bytes(octets, signed: bool = ...): ...
def to_bytes(value, signed: bool = ..., length: int = ...): ...
def bitLength(number): ...



from pyasn1.type import base
from pyasn1.type.tag import TagSet

class EndOfOctets(base.SimpleAsn1Type):
    defaultValue: int
    tagSet: TagSet
    def __new__(cls, *args, **kwargs): ...

endOfOctets: EndOfOctets



from pyasn1.codec.cer import decoder

class BitStringDecoder(decoder.BitStringDecoder):
    supportConstructedForm: bool

class OctetStringDecoder(decoder.OctetStringDecoder):
    supportConstructedForm: bool

class Decoder(decoder.Decoder):
    supportIndefLength: bool

decode: Decoder



from _typeshed import Incomplete
from collections.abc import Generator

class NamedValues:
    def __init__(self, *args, **kwargs) -> None: ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...
    def __hash__(self): ...
    def __getitem__(self, key): ...
    def __len__(self) -> int: ...
    def __contains__(self, key) -> bool: ...
    def __iter__(self): ...
    def values(self): ...
    def keys(self): ...
    def items(self) -> Generator[Incomplete, None, None]: ...
    def __add__(self, namedValues): ...
    def clone(self, *args, **kwargs): ...
    def getName(self, value): ...
    def getValue(self, name): ...
    def getValues(self, *names): ...



tagClassUniversal: int
tagClassApplication: int
tagClassContext: int
tagClassPrivate: int
tagFormatSimple: int
tagFormatConstructed: int
tagCategoryImplicit: int
tagCategoryExplicit: int
tagCategoryUntagged: int

class Tag:
    def __init__(self, tagClass, tagFormat, tagId) -> None: ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...
    def __hash__(self): ...
    def __getitem__(self, idx): ...
    def __iter__(self): ...
    def __and__(self, otherTag): ...
    def __or__(self, otherTag): ...
    @property
    def tagClass(self): ...
    @property
    def tagFormat(self): ...
    @property
    def tagId(self): ...

class TagSet:
    def __init__(self, baseTag=..., *superTags) -> None: ...
    def __add__(self, superTag): ...
    def __radd__(self, superTag): ...
    def __getitem__(self, i): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...
    def __hash__(self): ...
    def __len__(self) -> int: ...
    @property
    def baseTag(self): ...
    @property
    def superTags(self): ...
    def tagExplicitly(self, superTag): ...
    def tagImplicitly(self, superTag): ...
    def isSuperTagSetOf(self, tagSet): ...
    def getBaseTag(self): ...



from collections.abc import Container, Mapping

from pyasn1.type.base import Asn1Type

class TagMap:
    def __init__(
        self,
        presentTypes: Mapping[TagMap, Asn1Type] | None = ...,
        skipTypes: Container[TagMap] | None = ...,
        defaultType: Asn1Type | None = ...,
    ) -> None: ...
    def __contains__(self, tagSet) -> bool: ...
    def __getitem__(self, tagSet): ...
    def __iter__(self): ...
    @property
    def presentTypes(self): ...
    @property
    def skipTypes(self): ...
    @property
    def defaultType(self): ...
    def getPosMap(self): ...
    def getNegMap(self): ...
    def getDef(self): ...



from abc import abstractmethod
from collections import OrderedDict

class AbstractItemEncoder:
    @abstractmethod
    def encode(self, value, encodeFun, **options) -> None: ...

class BooleanEncoder(AbstractItemEncoder):
    def encode(self, value, encodeFun, **options): ...

class IntegerEncoder(AbstractItemEncoder):
    def encode(self, value, encodeFun, **options): ...

class BitStringEncoder(AbstractItemEncoder):
    def encode(self, value, encodeFun, **options): ...

class OctetStringEncoder(AbstractItemEncoder):
    def encode(self, value, encodeFun, **options): ...

class TextStringEncoder(AbstractItemEncoder):
    def encode(self, value, encodeFun, **options): ...

class NullEncoder(AbstractItemEncoder):
    def encode(self, value, encodeFun, **options) -> None: ...

class ObjectIdentifierEncoder(AbstractItemEncoder):
    def encode(self, value, encodeFun, **options): ...

class RealEncoder(AbstractItemEncoder):
    def encode(self, value, encodeFun, **options): ...

class SetEncoder(AbstractItemEncoder):
    protoDict = dict
    def encode(self, value, encodeFun, **options): ...

class SequenceEncoder(SetEncoder):
    protoDict = OrderedDict

class SequenceOfEncoder(AbstractItemEncoder):
    def encode(self, value, encodeFun, **options): ...

class ChoiceEncoder(SequenceEncoder): ...

class AnyEncoder(AbstractItemEncoder):
    def encode(self, value, encodeFun, **options): ...

class Encoder:
    def __init__(self, tagMap, typeMap=...) -> None: ...
    def __call__(self, value, **options): ...

encode: Encoder



class PyAsn1Error(Exception): ...
class ValueConstraintError(PyAsn1Error): ...
class SubstrateUnderrunError(PyAsn1Error): ...

class PyAsn1UnicodeError(PyAsn1Error, UnicodeError):
    def __init__(self, message, unicode_error: UnicodeError | None = ...) -> None: ...

class PyAsn1UnicodeDecodeError(PyAsn1UnicodeError, UnicodeDecodeError): ...
class PyAsn1UnicodeEncodeError(PyAsn1UnicodeError, UnicodeEncodeError): ...



from setuptools import setup

name = "types-pyasn1"
description = "Typing stubs for pyasn1"
long_description = '''
## Typing stubs for pyasn1

This is a PEP 561 type stub package for the `pyasn1` package. It
can be used by type-checking tools like
[mypy](https://github.com/python/mypy/),
[pyright](https://github.com/microsoft/pyright),
[pytype](https://github.com/google/pytype/),
PyCharm, etc. to check code that uses
`pyasn1`. The source for this package can be found at
https://github.com/python/typeshed/tree/main/stubs/pyasn1. All fixes for
types and metadata should be contributed there.

See https://github.com/python/typeshed/blob/main/README.md for more details.
This package was generated from typeshed commit `c4c4bee8aa368b8c05d06559904531596e8a7be6`.
'''.lstrip()

setup(name=name,
      version="0.4.0.1",
      description=description,
      long_description=long_description,
      long_description_content_type="text/markdown",
      url="https://github.com/python/typeshed",
      project_urls={
          "GitHub": "https://github.com/python/typeshed",
          "Changes": "https://github.com/typeshed-internal/stub_uploader/blob/main/data/changelogs/pyasn1.md",
          "Issue tracker": "https://github.com/python/typeshed/issues",
          "Chat": "https://gitter.im/python/typing",
      },
      install_requires=[],
      packages=['pyasn1-stubs'],
      package_data={'pyasn1-stubs': ['__init__.pyi', 'codec/__init__.pyi', 'codec/ber/__init__.pyi', 'codec/ber/decoder.pyi', 'codec/ber/encoder.pyi', 'codec/ber/eoo.pyi', 'codec/cer/__init__.pyi', 'codec/cer/decoder.pyi', 'codec/cer/encoder.pyi', 'codec/der/__init__.pyi', 'codec/der/decoder.pyi', 'codec/der/encoder.pyi', 'codec/native/__init__.pyi', 'codec/native/decoder.pyi', 'codec/native/encoder.pyi', 'compat/__init__.pyi', 'compat/binary.pyi', 'compat/calling.pyi', 'compat/dateandtime.pyi', 'compat/integer.pyi', 'compat/octets.pyi', 'compat/string.pyi', 'debug.pyi', 'error.pyi', 'type/__init__.pyi', 'type/base.pyi', 'type/char.pyi', 'type/constraint.pyi', 'type/error.pyi', 'type/namedtype.pyi', 'type/namedval.pyi', 'type/opentype.pyi', 'type/tag.pyi', 'type/tagmap.pyi', 'type/univ.pyi', 'type/useful.pyi', 'METADATA.toml']},
      license="Apache-2.0 license",
      classifiers=[
          "License :: OSI Approved :: Apache Software License",
          "Programming Language :: Python :: 3",
          "Typing :: Stubs Only",
      ]
)



class AbstractConstraint:
    def __init__(self, *values) -> None: ...
    def __call__(self, value, idx: int | None = ...) -> None: ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
    def __lt__(self, other): ...
    def __le__(self, other): ...
    def __gt__(self, other): ...
    def __ge__(self, other): ...
    def __bool__(self) -> bool: ...
    def __hash__(self): ...
    def getValueMap(self): ...
    def isSuperTypeOf(self, otherConstraint): ...
    def isSubTypeOf(self, otherConstraint): ...

class SingleValueConstraint(AbstractConstraint):
    def __contains__(self, item) -> bool: ...
    def __iter__(self): ...
    def __add__(self, constraint): ...
    def __sub__(self, constraint): ...

class ContainedSubtypeConstraint(AbstractConstraint): ...
class ValueRangeConstraint(AbstractConstraint): ...
class ValueSizeConstraint(ValueRangeConstraint): ...
class PermittedAlphabetConstraint(SingleValueConstraint): ...
class ComponentPresentConstraint(AbstractConstraint): ...
class ComponentAbsentConstraint(AbstractConstraint): ...
class WithComponentsConstraint(AbstractConstraint): ...
class InnerTypeConstraint(AbstractConstraint): ...
class ConstraintsExclusion(AbstractConstraint): ...

class AbstractConstraintSet(AbstractConstraint):
    def __getitem__(self, idx): ...
    def __iter__(self): ...
    def __add__(self, value): ...
    def __radd__(self, value): ...
    def __len__(self) -> int: ...

class ConstraintsIntersection(AbstractConstraintSet): ...
class ConstraintsUnion(AbstractConstraintSet): ...
